#
# spec file for package delve
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define shortname dlv

Name:           delve
Version:        1.20.0
Release:        bp155.1.6
Summary:        Static website generator written in Go
License:        MIT
Group:          Development/Languages/Go
URL:            https://github.com/go-delve/delve
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.16
ExcludeArch:    s390x ppc64le %arm

%description
Delve is a debugger for the Go programming language. The goal of
the project is to provide a simple, full featured debugging tool
for Go. Delve should be easy to invoke and easy to use. Chances are
if you're using a debugger, things aren't going your way. With that
in mind, Delve should stay out of your way as much as possible.

%prep
%autosetup -a 1

%build
# Build the binary, use PIE unless on ppc64le or s390x
# Upstream reports these as unsupported platforms so meta pkg disable
go build \
   -mod=vendor \
%ifnarch ppc64 s390x
   -buildmode=pie \
%endif
   -o %{shortname} \
   ./cmd/%{shortname}
# Upstream Makefile uses these options to build static
# fails with /usr/bin/ld: cannot find -lc
# -ldflags "-extldflags -static" \

%install
# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"

%files
%doc README.md
%doc Documentation
%license LICENSE
%{_bindir}/%{shortname}

%changelog
* Thu Dec  8 2022 jkowalczyk@suse.com
- Update to version 1.20.0:
  * *: CHANGELOG and bump to version 1.20.0 (#3209)
  * Test windows/arm64 pipeline (#3200)
  * proc: extend macOS workaround to amd64 (#3204)
  * proc/gdbserver: set child process pgrp as foreground group (#3205)
  * *: early fixes for go1.20 (#3180)
  * Run CI tests on windows/arm64 agents (#3198)
  * cmd/dlv: Include hidden flag -c for coredumpctl support (#3195)
  * G struct offset is a pointer to an offset since go1.20 (#3196)
  * proc: prefer addresses when setting a breakpoint (#3193)
  * pkg/proc: fix arm64 linux cgo stacktrace (#3192)
  * Two fixes to type cast evaluation (#3186)
  * bininfo: Log when the file listed in .gnu_debuglink is not found (#3188)
  * service/debugger: allow setting a breakpoint with a specific ID (#3185)
  * proc/gdbserial/gdbserver: Don't pass DYLD_INSERT_LIBRARIES to debugserver (#3181)
  * proc: fix index access to already-loaded string values (#3184)
  * service/debugger: Assume current dir for exec (#3167)
  * pkg/terminal: Improve error when unable to read history file (#3169)
  * Add type to call evaluation and expression evaluation (#3172)
  * proc/native: acquire debug programs privilege on Windows (#3162)
  * pkg: fix a few function names on comments
  * service/dap: fix nil ptr deref when current addr is not in a func (#3157)
  * proc: disable TestCGONext on darwin/amd64 (#3160)
  * proc: remove import "C" for linux/386 backend (#3159)
  * proc,terminal: allow setting suspended breakpoints (#3154)
  * Documentation: add homebrew installation instructions back again
  * cmd/dlv: disable TestTraceMultipleGoroutines on FreeBSD (#3144)
  * proc: allow type casts between compatible types (#3149)
  * proc: remove old method to resolve the type of an interface to a DIE (#3150)
  * proc,service/debugger: track how breakpoints were originally set (#3148)
  * proc,service: change FindLocation to work with multiple targets (#3103)
  * service/dap: show full value when evaluating log messages (#3141)
  * proc,_scripts/rtype.go: add rtype annotations for g.atomicstatus (#3143)
  * proc: fix openSeparateDebugInfo backwards compatibility path (#3145)
  * proc: fix cast to empty interface type (#3146)
  * proc/native: fix support_sentinel_darwin.go name (#3147)
  * Add support for windows/arm64 (#3063)
  * service/debugger: merge attachErrorMessage, verifyBinaryFormat (#3142)
  * terminal: do not use WaitSince as unix time (#3139)
  * proc: fix hang caused by g.atomicstatus has change to atomic.Uint32 (#3129)
  * go.mod,proc: upgrade golang.org/x/sys/unix (#3134)
  * proc: reduntant type conversion (#3131)
  * terminal: remove leftover GOPATH references (#3117)
  * Add Debugger to UIs list in EditorIntegration (#3127)
  * Documentation: reverse step, next and stepout (#3119)
* Tue Aug 23 2022 jkowalczyk@suse.com
- Update to version 1.9.1:
  * v1.9.1 (#3116)
  * proc: make sure logical breakpoints map exists (#3115)
  * go.mod: update starlark dependency (#3112)
  * terminal: send large output to pager (#3060)
  * *: switch to int64 for goroutine IDs (#3110)
  * proc: use stdlib to compute CRC for gnu_debuglink section (#3105)
  * _scripts: fix CI on go1.19/linux/386 (#3100)
  * service/dap: Add support for empty string in substitutePath (#3088)
  * proc: fuse evalToplevelTypeCast and evalTypeCast (#3057)
  * _scripts: fix command to download Go version (#3099)
  * service/debugger: refactor state/collectBreakpointInfo for TargetGroup (#3064)
  * proc: do not panic reading bad G struct (#3098)
  * TeamCity,goversion: bump test matrix (#3092)
  * pkg/dwarf/line: Fix parsing file table for DWARFv5 (#3090)
  * :* Improve trace subcommand output (#3091)
  * Documentation: fix documentation of examinemem (#3087)
  * fix StepInstruction on 1 byte instruction with a software breackpoint (#3084)
  * pkg/proc/internal/ebpf: Fix handling of entry / return (#3081)
  * service/dap: fix indexing bug for maps (#3068)
  * pkg/proc/internal/ebpf: Fix size of ebpf type for fn_addr (#3080)
  * proc/native: refactor windows framework (#3079)
  * terminal/command: 'goroutines' command add new flags '-exec command' (#3044)
  * proc: support gnu_debuglink section (#3073)
  * pkg/locspec: support exact match in SubstitutePath (#3075)
  * proc/internal/ebpf: drop dependency on cgo (#3072)
  * cmd/dlv,proc: misc improvements to trace subcommand (#3069)
  * dwarf/op,proc: output register name when printing location exprs (#3052)
  * service/dap: limit disassembly range (#3045)
  * proc,service/debugger: introduce TargetGroup abstraction (#3030)
  * terminal: add ability to show disassembly instead of source (#3047)
  * terminal/command: add -per-g-hitcount option to condition command (#3055)
  * _scripts: un-pin mingw version (#3046)
* Mon Aug 22 2022 Dirk Müller <dmueller@suse.com>
- update list of excluded archs with those that raise
  your_operating_system_and_architecture_combination_is_not_supported_by_delve exception
* Wed Jul  6 2022 jkowalczyk@suse.com
- Update to version 1.9.0:
  * *: Bump version to 1.9.0 (#3054)
  * vendor: update version of go/packages to 0.1.11 (#3053)
  * proc: fix arm64SwitchStack for go1.19 (#3038)
  * dwarf/frame: discard indirect flag reading personality func in eh_frame (#3032)
  * proc/native: fix Ctrl-C handling on non-headless instances on windows (#3039)
  * proc: map access with string literal key should always succeed (#3036)
  * testcase: remove accidental debug binary (#3035)
  * *: run go1.19 'go fmt' on everything and fix problems (#3031)
  * proc/gdbserver: ignore spurious stop packet from debugserver (#3021)
  * service/test,proc: move variable evaluation test to pkg/proc (#3024)
  * proc: fix prettyprint for register components with large values (#3022)
  * go.mod: use pseudo verion for github.com/go-delve/liner (#3026)
  * pkg/proc: fix and improve freebsd register handling (#3019)
  * proc/native: fix Windows build (#3023)
  * proc,service: represent logical breakpoints explicitly (#2946)
  * dap: add MultiClientCloseServerMock and fix test shutdown leak (#3011)
  * pkg/terminal: Add auto-complete for local variables (#3004)
  * proc: fix fatal throw breakpoint on go1.19 (#3009)
  * dap: remote attach must not use terminateDebuggee in single-client launch mode (#2995)
  * proc/gdbserver: fix function call injection on rr (#3007)
  * proc: fix RFLAGS corruption after call injection on amd64 (#3002)
  * proc: fixes concerning call injection on freebsd and rr (#3000)
  * Documentation: document substitute-path more (#2998)
  * proc/core: return true for calls to Recorded (#2979)
  * proc: support function call injection on arm64 (#2996)
  * Documentation: add DAP launch/attach configuration matrix (#2991)
  * _scripts/test_linux.sh,_scripts/test_windows.ps1: always return exit code 0 when testing on tip (#2997)
  * proc: fix autogenerated helper skip on linux/386 PIE builds (#2975)
  * _scripts: always return exit code 0 when testing on tip (#2980)
  * proc: unlock OS thread on exit from handlePtraceFuncs (#2972)
  * service/debugger: close executable file (#2976)
  * proc: add support for setting additional registers on freebsd/amd64 (#2981)
  * service/debugger: make TestDebugger_LaunchWithTTY pass on FreeBSD (#2982)
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- s390x is not in list of supported CPUs. Disable building for s390x.
* Wed May 18 2022 jkowalczyk@suse.com
- Initial package version 1.8.3:
  * Documentation: expand DAP launch/attach configurations section (#2977)
  * Documentation: Fix example block in cli README (#2974)
  * _scripts/make: do not exit if git SHA ID can not be retrieved (#2973)
  * proc: skip autogenerated functions correctly (#2959)
  * dlv dap: pass disable-aslr to backend (#2965)
  * gobuild: drop support for building on Go < 1.10 (#2960)
  * Documentation/api/dap/README: add dlv dap usage link (#2957)
  * CHANGELOG.md: fix date typos (#2956)
  * proc/gdbserial: shut down debuggee when failing to debug (#2953)
  * debugger: clarify no debug info errors (#2954)
  * dlv_test: fix TestChildProcessExitWhenNoDebugInfo to actually test strip binary (#2949)
  * proc: allow low index == len in reslice (#2951)
  * proc,service: pretty print time.Time variables (#2865)
  * *: fix some typos
  * Prefer locspec to linespec (#2941)
  * service/dap: support terminateDebuggee option for attach only (#2940)
  * proc: move resume notify and manual stop handling to Target (#2921)
  * proc/native/linux: replace uses of unix.Iovec for target addresses (#2922)
  * Documentation/api/dap/README: add release version links (#2923)
  * service-*: conform to godoc comments (#2916)
